From e634664058e6ca6d4ff95bca81e7a9b62fac29aa Mon Sep 17 00:00:00 2001
From: Robert Haas <rhaas@postgresql.org>
Date: Wed, 16 Nov 2016 11:39:16 -0500
Subject: [PATCH 3/3] Reduce transaction status debugging messages to DEBUG5.

These messages occur very frequently on busy systems, and therefore
make it impossible to use log_min_messages >= DEBUG3 on such systems.
They're only likely to be useful to developers, so reduce them to
DEBUG5 to avoid unnecessary log chatter.
---
 src/backend/access/transam/xact.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/backend/access/transam/xact.c b/src/backend/access/transam/xact.c
index 67b6f1b..9580596 100644
--- a/src/backend/access/transam/xact.c
+++ b/src/backend/access/transam/xact.c
@@ -4944,7 +4944,7 @@ static void
 ShowTransactionState(const char *str)
 {
 	/* skip work if message will definitely not be printed */
-	if (log_min_messages <= DEBUG3 || client_min_messages <= DEBUG3)
+	if (log_min_messages <= DEBUG5 || client_min_messages <= DEBUG5)
 		ShowTransactionStateRec(str, CurrentTransactionState);
 }
 
@@ -4972,7 +4972,7 @@ ShowTransactionStateRec(const char *str, TransactionState s)
 		ShowTransactionStateRec(str, s->parent);
 
 	/* use ereport to suppress computation if msg will not be printed */
-	ereport(DEBUG3,
+	ereport(DEBUG5,
 			(errmsg_internal("%s(%d) name: %s; blockState: %s; state: %s, xid/subid/cid: %u/%u/%u%s%s",
 							 str, s->nestingLevel,
 							 PointerIsValid(s->name) ? s->name : "unnamed",
-- 
2.5.4 (Apple Git-61)

